:root {
  --regular-text-color: black;
  --background-color: white;
  --header-color: darkgray;
  --anchor-color: #0022cc;
  --shadow-color: #00000044;
}

@media (prefers-color-scheme: dark) {
  :root {
    --regular-text-color: white;
    --background-color: black;
    --header-color: darkgray;
    --anchor-color: #3366ff;
    --shadow-color: #ffffff44;
  }
}

body {
	background: var(--background-color);
	color: var(--regular-text-color);
}

a:link {
	color: var(--anchor-color);
}

#rkward_welcome #main {
	width: 100%;
	margin: auto;
	display: flex;
	flex-flow: row wrap;
	justify-content: center;
}

#rkward_welcome #main h1 {
	width: 100%;
}

#rkward_welcome #main h2 {
	margin: 0.5em 0;
	padding: 0.2em;
	display: inline;
	border: 1px solid var(--shadow-color);
	border-radius: .5em;
}

#rkward_welcome #navigation {
	display: none;
}

#rkward_welcome div {
	width: 46%;
	margin: 2%;
	padding: 0em 1em;
	box-sizing: border-box;
}

#rkward_welcome div div {
	box-shadow: var(--shadow-color) .1em .5em .8em;
}

#rkward_welcome li {
	width: 100%;
	text-overflow: ellipsis;
	direction: rtl;
	overflow: hidden;
	white-space: nowrap;
	clear: left;
}

/* Note: Text ellipsis on left-hand side does not allow for regular (left-aligned) bullets in <li>. These are added, separately, here. */
#rkward_welcome li::before {
	content: "\2022";
	float: left;
	direction: ltr;
	width: 1em;
}

#main {
	margin-right: 11em;
}

#main h1 {
	font-size: 1.5em;
	color: var(--header-color);
	text-align: center;
	margin-top: 1em;
	margin-bottom: 1em;
	padding: 0;
}

#main h2 {
	font-size: 1.2em;
	color: var(--header-color);
	margin-top: 1em;
	margin-bottom: 0.5em;
	padding: 0;
}

#main h3 {
	font-size: 1.1em;
	color: var(--header-color);
	margin-top: 1em;
	margin-bottom: 0em;
	padding: 0;
}

#main h4 {
	font-size: 1em;
	font-weight: bold;
	color: var(--header-color);
	margin-top: 0.5em;
	margin-bottom: 0em;
	padding: 0;
}

#main p {
	margin-top: 0em;
	margin-bottom: 0.5em;
	color: var(--text-color);
	padding: 0;
}

#navigation {
	position: fixed;
	top: 1em;
	right: 0.5em;
	width: 10em;
	border: 1px solid silver;
}

#navigation h1 {
	font-size: 1em;
	color: var(--header-color);
	margin-top: 0em;
	margin-bottom: 0.5em;
}

#navigation p {
	font-size: 0.9em;
	margin-top: 0em;
	margin-bottom: 0.5em;
	text-indent: -1em;
	margin-left: 1.5em;
	margin-right: 0.2em;
}
